<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Hay vida fuera del navegador!!!!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Versión %1</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licenciado a: %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 es Software Libre pero su desarrollo toma tiempo.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Por favor &lt;a href=&apos;%1&apos;&gt;dona&lt;/a&gt; para apoyar el desarrollo de %2</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Traducir %1 a tu idioma nativo usando %2</translation>
    </message>
    <message>
        <source>Powered by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open-source software</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ícono diseñado por %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Liberado bajo la licencia &lt;a href=&apos;%1&apos;&gt; GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Introduzca su detalle de licencia</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>Correo &amp;electrónico:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Código</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Por favor licencia %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Esta demostración ha expirado</translation>
    </message>
    <message>
        <source>The full version allows you to watch videos without interruptions.</source>
        <translation>La versión completa te permite ver vídeos sin interrupciones</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Sin una licencia, la aplicación expirará en %1 dias.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Comprando la versión completa, permitirás el desarrollo y el trabajo duro que he puesto creando %1</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Usar Demostración</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Introduzca Licencia</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Comprar Licencia</translation>
    </message>
</context>
<context>
    <name>AppWidget</name>
    <message>
        <source>Download</source>
        <translation>Descargar</translation>
    </message>
</context>
<context>
    <name>ChannelAggregator</name>
    <message>
        <source>By %1</source>
        <translation>Por %1</translation>
    </message>
    <message numerus="yes">
        <source>You have %n new video(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>ChannelItemDelegate</name>
    <message>
        <source>All Videos</source>
        <translation>Todos los vídeos</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Vídeos sin ver</translation>
    </message>
</context>
<context>
    <name>ChannelView</name>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Last Updated</source>
        <translation>Últimos Actualizados</translation>
    </message>
    <message>
        <source>Last Added</source>
        <translation>Últimos añadidos</translation>
    </message>
    <message>
        <source>Last Watched</source>
        <translation>Últimos vistos</translation>
    </message>
    <message>
        <source>Most Watched</source>
        <translation>Más vistos</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
    <message>
        <source>Mark all as watched</source>
        <translation>Marcar todo como visto</translation>
    </message>
    <message>
        <source>Show Updated</source>
        <translation>Mostrar actualizados</translation>
    </message>
    <message>
        <source>You have no subscriptions. Use the star symbol to subscribe to channels.</source>
        <translation>No tienes suscripciones. Usa el símbolo de estrella para suscribirte a los canales.</translation>
    </message>
    <message>
        <source>All Videos</source>
        <translation>Todos los vídeos</translation>
    </message>
    <message>
        <source>Unwatched Videos</source>
        <translation>Vídeos no vistos</translation>
    </message>
    <message>
        <source>Mark as Watched</source>
        <translation>Marcar como visto</translation>
    </message>
    <message>
        <source>Unsubscribe</source>
        <translation>Cancelar suscripción</translation>
    </message>
    <message>
        <source>There are no updated subscriptions at this time.</source>
        <translation>No hay suscripciones actualizadas</translation>
    </message>
</context>
<context>
    <name>DataUtils</name>
    <message>
        <source>Just now</source>
        <translation>Justo ahora</translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>K</source>
        <comment>K as in Kilo, i.e. thousands</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>M</source>
        <comment>M stands for Millions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B</source>
        <comment>B stands for Billions</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation>%1 vistas</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s) ago</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>bytes/sec</source>
        <translation>bytes/seg</translation>
    </message>
    <message>
        <source>KB/sec</source>
        <translation>KB/seg</translation>
    </message>
    <message>
        <source>MB/sec</source>
        <translation>MB/seg</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>segundos</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutos</translation>
    </message>
    <message>
        <source>%4 %5 remaining</source>
        <translation>%4 %5 restante</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>%1 downloaded in %2</source>
        <translation>Descargados %1 en %2</translation>
    </message>
    <message>
        <source>Download finished</source>
        <translation>Descarga terminada</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>DownloadSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Cambiar ubicación...</translation>
    </message>
    <message>
        <source>Choose the download location</source>
        <translation>Seleccionar donde descargar</translation>
    </message>
    <message>
        <source>Download location changed.</source>
        <translation>Ubicación de descarga cambiada.</translation>
    </message>
    <message>
        <source>Current downloads will still go in the previous location.</source>
        <translation>Las descargas actuales seguiran en la ubicación anterior</translation>
    </message>
    <message>
        <source>Downloading to: %1</source>
        <translation>Descargando en: %1</translation>
    </message>
</context>
<context>
    <name>DownloadView</name>
    <message>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
</context>
<context>
    <name>Extra</name>
    <message>
        <source>The executable file has been tempered with, maybe by a virus.</source>
        <translation>El ejecutable ha sido modificado, probablemente sea un virus</translation>
    </message>
    <message>
        <source>%1 will not run. Try installing again.</source>
        <translation>%1 no puede ejecutarse. Intenta reinstalándolo</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproducir/Pausar</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Detener reproducción después del track actual</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Pista siguiente</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Pista anterior</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Incrementar volumen</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Reducir volumen</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Silenciar</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Buscar hacia adelante</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Buscar hacia atrás</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Search</source>
        <translation>Búsqueda</translation>
    </message>
    <message>
        <source>Find videos and channels by keyword</source>
        <translation>Buscar vídeos y canales por palabra clave</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Navegar</translation>
    </message>
    <message>
        <source>Browse videos by category</source>
        <translation>Navegar vídeos por categoría</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Suscripciones</translation>
    </message>
    <message>
        <source>Channel subscriptions</source>
        <translation>Suscripciones a canales</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Siéntete a gusto</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ventana</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimizar</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Detener</translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Detener reproducción e ir haca la vista de búsqueda</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>Ante&amp;rior</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Ir al track anterior</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>S&amp;altar</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Saltar al siguiente video</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Reproducir</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Reiniciar reproducción</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Pantalla Completa</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Ir a Pantalla Completa</translation>
    </message>
    <message>
        <source>&amp;Compact Mode</source>
        <translation>Modo &amp;compacto</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ocultar la lista de reproducción y la barra de tareas</translation>
    </message>
    <message>
        <source>Open the &amp;YouTube Page</source>
        <translation>Abrir la página de &amp;YouTube</translation>
    </message>
    <message>
        <source>Go to the YouTube video page and pause playback</source>
        <translation>Ir a la página YouTube del vídeo y pausar reproducción</translation>
    </message>
    <message>
        <source>Copy the YouTube &amp;Link</source>
        <translation>Copiar el víncu&amp;lo YouTube</translation>
    </message>
    <message>
        <source>Copy the current video YouTube link to the clipboard</source>
        <translation>Copiar el enlace de YouTube al portapapeles</translation>
    </message>
    <message>
        <source>Copy the Video Stream &amp;URL</source>
        <translation>Copiar la URL de la difusión de vídeo</translation>
    </message>
    <message>
        <source>Copy the current video stream URL to the clipboard</source>
        <translation>Copiar la dirección de la difusión de vídeo al portapapeles</translation>
    </message>
    <message>
        <source>Find Video &amp;Parts</source>
        <translation>Buscar las &amp;partes del vídeo</translation>
    </message>
    <message>
        <source>Find other video parts hopefully in the right order</source>
        <translation>Buscar otras partes del vídeo en el orden correcto</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Elimina&amp;r</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Eliminar los vídeos seleccionados de la lista de reproducción</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover &amp;arriba</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Mover hacia arriba los vídeos seleccionados en la lista de reproducción</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover a&amp;bajo</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Mover hacia abajo los vídeos seleccionados en lista de reproducción</translation>
    </message>
    <message>
        <source>&amp;Clear Recent Searches</source>
        <translation>Limpiar búsquedas re&amp;cientes</translation>
    </message>
    <message>
        <source>Clear the search history. Cannot be undone.</source>
        <translation>Limpiar el historial de búsqueda. No puede ser deshecho.</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Adiós</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Sitio &amp;Web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 en el Web</translation>
    </message>
    <message>
        <source>Make a &amp;Donation</source>
        <translation>Hacer una &amp;donación</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor apoya el desarrollo continuo de %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Información acerca de %1</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Búsqueda</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Silenciar volumen</translation>
    </message>
    <message>
        <source>&amp;Manually Start Playing</source>
        <translation>Iniciar reproducción &amp;manualmente</translation>
    </message>
    <message>
        <source>Manually start playing videos</source>
        <translation>Reproduce vídeos de manera manual</translation>
    </message>
    <message>
        <source>&amp;Downloads</source>
        <translation>&amp;Descargas</translation>
    </message>
    <message>
        <source>Show details about video downloads</source>
        <translation>Mostrar detalles acerca de las descargas de vídeos</translation>
    </message>
    <message>
        <source>&amp;Download</source>
        <translation>&amp;Descarga</translation>
    </message>
    <message>
        <source>Download the current video</source>
        <translation>Descargar el vídeo actual</translation>
    </message>
    <message>
        <source>Take &amp;Snapshot</source>
        <translation>Capturar &amp;fotogramas</translation>
    </message>
    <message>
        <source>&amp;Subscribe to Channel</source>
        <translation>&amp;Suscribir al Canal</translation>
    </message>
    <message>
        <source>Share the current video using %1</source>
        <translation>Compartir el vídeo actual usando %1</translation>
    </message>
    <message>
        <source>&amp;Email</source>
        <translation>Correo &amp;Electrónico</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Correo electrónico</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>&amp;Float on Top</source>
        <translation>&amp;Mantener arriba</translation>
    </message>
    <message>
        <source>&amp;Stop After This Video</source>
        <translation>Detener de&amp;spués de este vídeo</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Reportar un problema</translation>
    </message>
    <message>
        <source>&amp;Refine Search...</source>
        <translation>&amp;Refinar búsqueda</translation>
    </message>
    <message>
        <source>More...</source>
        <translation>Más...</translation>
    </message>
    <message>
        <source>&amp;Related Videos</source>
        <translation>Vídeos &amp;Relacionados</translation>
    </message>
    <message>
        <source>Watch videos related to the current one</source>
        <translation>Ver vídeos relacionados con el actual</translation>
    </message>
    <message>
        <source>Open in &amp;Browser...</source>
        <translation>Abrir en Navegador...</translation>
    </message>
    <message>
        <source>Restricted Mode</source>
        <translation>Modo restringido</translation>
    </message>
    <message>
        <source>Hide videos that may contain inappropriate content</source>
        <translation>Ocultar vídeos que pueden tener contenido inapropiado</translation>
    </message>
    <message>
        <source>Toggle &amp;Menu Bar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Amas %1? Calíficalo!</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Comprar %1...</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicación</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>Re&amp;producir</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Lista de re&amp;producción</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>&amp;Vídeo</translation>
    </message>
    <message>
        <source>&amp;Share</source>
        <translation>&amp;Compartir</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Presiona %1 para aumentar el volumen, %2 para reducirlo.</translation>
    </message>
    <message>
        <source>Choose your content location</source>
        <translation>Introduce la ubicación de tu contenido</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abriendo %1</translation>
    </message>
    <message>
        <source>Do you want to exit %1 with a download in progress?</source>
        <translation>Deseas salir de %1 con una descarga en progreso?</translation>
    </message>
    <message>
        <source>If you close %1 now, this download will be cancelled.</source>
        <translation>SI cierras %1 ahora, esta descarga será cancelada.</translation>
    </message>
    <message>
        <source>Close and cancel download</source>
        <translation>Cerrar y cancelar descarga</translation>
    </message>
    <message>
        <source>Wait for download to finish</source>
        <translation>Esperarando a que termine la descarga</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Error: %1</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Pausar reproducción</translation>
    </message>
    <message>
        <source>&amp;Loading...</source>
        <translation>&amp;Cargando...</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Mantener en pantalla completa</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tiempo restante: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volumen a %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Audio silenciado</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Audio sin silenciar</translation>
    </message>
    <message>
        <source>Maximum video definition set to %1</source>
        <translation>Resolución de vídeo máxima definida en %1</translation>
    </message>
    <message>
        <source>Your privacy is now safe</source>
        <translation>Tu privacidad está segura ahora</translation>
    </message>
    <message>
        <source>Downloads complete</source>
        <translation>Descarga completa</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>Está disponible %1 versión %2.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Recordarme después</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <source>You can still access the menu bar by pressing the ALT key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>You can now paste the YouTube link into another application</source>
        <translation>Ahora puedes pegar el vínculo YouTube en otra aplicación</translation>
    </message>
    <message>
        <source>You can now paste the video stream URL into another application</source>
        <translation>Puedes pegar el URL de la difusión de vídeo en otra aplicación</translation>
    </message>
    <message>
        <source>The link will be valid only for a limited time.</source>
        <translation>El vínculo será válido sólo por un tiempo limitado</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Descargando %1</translation>
    </message>
    <message>
        <source>of</source>
        <comment>Used in video parts, as in '2 of 3'</comment>
        <translation>de</translation>
    </message>
    <message>
        <source>part</source>
        <comment>This is for video parts, as in 'Cool video - part 1'</comment>
        <translation>parte</translation>
    </message>
    <message>
        <source>episode</source>
        <comment>This is for video parts, as in 'Cool series - episode 1'</comment>
        <translation>episodio</translation>
    </message>
    <message>
        <source>Sent from %1</source>
        <translation>Enviado desde %1</translation>
    </message>
    <message>
        <source>Unsubscribe from %1</source>
        <translation>Desuscribir de %1</translation>
    </message>
    <message>
        <source>Subscribe to %1</source>
        <translation>Suscribir a %1</translation>
    </message>
    <message>
        <source>Switched to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unsubscribed from %1</source>
        <translation>Desuscribir de %1</translation>
    </message>
    <message>
        <source>Subscribed to %1</source>
        <translation>Suscrito a %1</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Una versión nueva de %1 está disponible!.</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 está disponible. Tú tienes %3</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Te gustaría descargarla ahora?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Saltar esta versión</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Recordarme despúes</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Instalar actualización</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
</context>
<context>
    <name>PickMessage</name>
    <message>
        <source>Pick a video</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PlaylistItemDelegate</name>
    <message>
        <source>%1 of %2 (%3) — %4</source>
        <translation>%1 de %2 (%3) - %4</translation>
    </message>
    <message>
        <source>Preparing</source>
        <translation>Preparando</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Completado</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Detenido</translation>
    </message>
    <message>
        <source>Stop downloading</source>
        <translation>Detener descarga</translation>
    </message>
    <message>
        <source>Show in %1</source>
        <translation>Mostrar en %1</translation>
    </message>
    <message>
        <source>Open parent folder</source>
        <translation>Abrir carpeta principal</translation>
    </message>
    <message>
        <source>Restart downloading</source>
        <translation>Reiniciar descarga</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>Show %1 More</source>
        <translation>Mostrar %1 más</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Sin vídeos</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>No hay mas vídeos</translation>
    </message>
</context>
<context>
    <name>RefineSearchWidget</name>
    <message>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation>Importancia</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Fecha</translation>
    </message>
    <message>
        <source>View Count</source>
        <translation>Conteo de visitas</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Calificación</translation>
    </message>
    <message>
        <source>Anytime</source>
        <translation>Cualquier tiempo</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
    <message>
        <source>7 Days</source>
        <translation>Hace 7 Dias</translation>
    </message>
    <message>
        <source>30 Days</source>
        <translation>Hace 30 Días</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Todo</translation>
    </message>
    <message>
        <source>Short</source>
        <translation>Pequeño</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Medio</translation>
    </message>
    <message>
        <source>Long</source>
        <translation>Largo</translation>
    </message>
    <message>
        <source>Less than 4 minutes</source>
        <translation>Menos de 4 minutos</translation>
    </message>
    <message>
        <source>Between 4 and 20 minutes</source>
        <translation>entre 4 y 20 minutos</translation>
    </message>
    <message>
        <source>Longer than 20 minutes</source>
        <translation>Mayor a 20 minutos</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Calidad</translation>
    </message>
    <message>
        <source>High Definition</source>
        <translation>Alta definición</translation>
    </message>
    <message>
        <source>720p or higher</source>
        <translation>720p o mayor</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
</context>
<context>
    <name>RegionsView</name>
    <message>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Búsqueda</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bienvenido a &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>to start watching videos.</source>
        <translation>para ver vídeos</translation>
    </message>
    <message>
        <source>a keyword</source>
        <translation>una palabra clave</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Introduzca</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Palabras claves recientes</translation>
    </message>
    <message>
        <source>Recent channels</source>
        <translation>Canales Recientes</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obtener la versión completa</translation>
    </message>
</context>
<context>
    <name>SidebarHeader</name>
    <message>
        <source>&amp;Back</source>
        <translation>Retroceder</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Forward to %1</source>
        <translation>Avanzar a %1 </translation>
    </message>
    <message>
        <source>Back to %1</source>
        <translation>Retroceder a %1</translation>
    </message>
</context>
<context>
    <name>SidebarWidget</name>
    <message>
        <source>Refine Search</source>
        <translation>Redefine búsqueda</translation>
    </message>
    <message>
        <source>Did you mean: %1</source>
        <translation>Querías decir: %1</translation>
    </message>
</context>
<context>
    <name>SnapshotSettings</name>
    <message>
        <source>Change location...</source>
        <translation>Cambiar ubicación...</translation>
    </message>
    <message>
        <source>Snapshot saved to %1</source>
        <translation>Fotograma capturado en %1</translation>
    </message>
    <message>
        <source>Snapshots location changed.</source>
        <translation>Ubicación de capturas cambiada</translation>
    </message>
</context>
<context>
    <name>StandardFeedsView</name>
    <message>
        <source>Most Popular</source>
        <translation>Más populares</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Downloading update...</source>
        <translation>Descargando actualización...</translation>
    </message>
    <message>
        <source>Downloading %1...</source>
        <translation>Descargando %1...</translation>
    </message>
</context>
<context>
    <name>YTRegions</name>
    <message>
        <source>Algeria</source>
        <translation>Algeria</translation>
    </message>
    <message>
        <source>Argentina</source>
        <translation>Argentina</translation>
    </message>
    <message>
        <source>Australia</source>
        <translation>Australia</translation>
    </message>
    <message>
        <source>Belgium</source>
        <translation>Bélgica</translation>
    </message>
    <message>
        <source>Brazil</source>
        <translation>Brasil</translation>
    </message>
    <message>
        <source>Canada</source>
        <translation>Cánada</translation>
    </message>
    <message>
        <source>Chile</source>
        <translation>Chile</translation>
    </message>
    <message>
        <source>Colombia</source>
        <translation>Colombia</translation>
    </message>
    <message>
        <source>Czech Republic</source>
        <translation>República checa</translation>
    </message>
    <message>
        <source>Egypt</source>
        <translation>Egipto</translation>
    </message>
    <message>
        <source>France</source>
        <translation>Francia</translation>
    </message>
    <message>
        <source>Germany</source>
        <translation>Alemania</translation>
    </message>
    <message>
        <source>Ghana</source>
        <translation>Ghana</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grecia</translation>
    </message>
    <message>
        <source>Hong Kong</source>
        <translation>Hong Kong</translation>
    </message>
    <message>
        <source>Hungary</source>
        <translation>Hungría</translation>
    </message>
    <message>
        <source>India</source>
        <translation>India</translation>
    </message>
    <message>
        <source>Indonesia</source>
        <translation>Indonesia</translation>
    </message>
    <message>
        <source>Ireland</source>
        <translation>Irlanda</translation>
    </message>
    <message>
        <source>Israel</source>
        <translation>Israel</translation>
    </message>
    <message>
        <source>Italy</source>
        <translation>Italia</translation>
    </message>
    <message>
        <source>Japan</source>
        <translation>Japón</translation>
    </message>
    <message>
        <source>Jordan</source>
        <translation>Jordania</translation>
    </message>
    <message>
        <source>Kenya</source>
        <translation>Kenia</translation>
    </message>
    <message>
        <source>Malaysia</source>
        <translation>Malasia</translation>
    </message>
    <message>
        <source>Mexico</source>
        <translation>México</translation>
    </message>
    <message>
        <source>Morocco</source>
        <translation>Marruecos</translation>
    </message>
    <message>
        <source>Netherlands</source>
        <translation>Países bajos</translation>
    </message>
    <message>
        <source>New Zealand</source>
        <translation>Nueva Zelanda</translation>
    </message>
    <message>
        <source>Nigeria</source>
        <translation>Nigeria</translation>
    </message>
    <message>
        <source>Peru</source>
        <translation>Perú</translation>
    </message>
    <message>
        <source>Philippines</source>
        <translation>Filipinas</translation>
    </message>
    <message>
        <source>Poland</source>
        <translation>Polonia</translation>
    </message>
    <message>
        <source>Russia</source>
        <translation>Rusia</translation>
    </message>
    <message>
        <source>Saudi Arabia</source>
        <translation>Arabia Saudita</translation>
    </message>
    <message>
        <source>Singapore</source>
        <translation>Singapur</translation>
    </message>
    <message>
        <source>South Africa</source>
        <translation>Sudáfrica</translation>
    </message>
    <message>
        <source>South Korea</source>
        <translation>Cora del Sur</translation>
    </message>
    <message>
        <source>Spain</source>
        <translation>España</translation>
    </message>
    <message>
        <source>Sweden</source>
        <translation>Suecia</translation>
    </message>
    <message>
        <source>Taiwan</source>
        <translation>Taiwan</translation>
    </message>
    <message>
        <source>Tunisia</source>
        <translation>Túnez</translation>
    </message>
    <message>
        <source>Turkey</source>
        <translation>Turkía</translation>
    </message>
    <message>
        <source>Uganda</source>
        <translation>ganda</translation>
    </message>
    <message>
        <source>United Arab Emirates</source>
        <translation>Emiratos Árabes Unidos</translation>
    </message>
    <message>
        <source>United Kingdom</source>
        <translation>Reino Unido</translation>
    </message>
    <message>
        <source>Yemen</source>
        <translation>Yemen</translation>
    </message>
    <message>
        <source>Worldwide</source>
        <translation>Mundial</translation>
    </message>
</context>
<context>
    <name>YTVideo</name>
    <message>
        <source>Cannot get video stream for %1</source>
        <translation>No se puede obtener el vídeo para %1</translation>
    </message>
</context>
</TS>